<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="+580"/>
        <source>Guymager needs to be started with root rights in order to perform acquisitions. You are not root and thus won&apos;t be able to acquire devices.
Continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="threadwrite.cpp" line="+1482"/>
        <source>Deleting %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main.cpp" line="-1"/>
        <source>Missing root rights</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dlgabort.cpp" line="+84"/>
        <location filename="dlgacquire.cpp" line="+812"/>
        <location filename="dlgdirsel.cpp" line="+107"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="dlgacquire.cpp" line="+7"/>
        <location line="+13"/>
        <location filename="dlgdirsel.cpp" line="+1"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="file.cpp" line="+68"/>
        <source>Linux dd raw image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Expert Witness Format, sub-format %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Advanced forensic image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="threadscan.cpp" line="+1441"/>
        <source>Guymager cannot scan the devices connected to this computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The selected scan method (&quot;%1&quot;) is not available. Do you want to try another scan method?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Try method &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="file.cpp" line="-29"/>
        <source>Creation of a clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linux split dd raw image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dlgacquire.cpp" line="+8"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_DeviceListModel</name>
    <message>
        <location filename="mainwindow.h" line="+48"/>
        <source>SerialNr</source>
        <translation>Serial
nr.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>LinuxDevice</source>
        <translation>Linux
device</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>NativePath</source>
        <translation>Native
path</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ByPath</source>
        <translation>By
path</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>State</source>
        <translation>State</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>AdditionalStateInfo</source>
        <translation>Additional
state info</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size</source>
        <translation>Size</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>HiddenAreas</source>
        <translation>Hidden
areas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>BadSectors</source>
        <translation>Bad
sectors</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Progress</source>
        <translation>Progress</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>AverageSpeed</source>
        <translation>Average
speed
[MB/s]</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>TimeRemaining</source>
        <translation>Time
remaining</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>FifoUsage</source>
        <translation>FIFO queues
usage
[%]</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SectorSizeLog</source>
        <translation>Sector
size
log.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SectorSizePhys</source>
        <translation>Sector
size
phys.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>CurrentSpeed</source>
        <translation>Current
speed
[MB/s]</translation>
    </message>
    <message>
        <location filename="dlgacquire.cpp" line="-392"/>
        <source>Remark</source>
        <translation>Remark</translation>
    </message>
    <message>
        <location filename="mainwindow.h" line="+2"/>
        <source>Examiner</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_DlgAbort</name>
    <message>
        <location filename="dlgabort.cpp" line="-7"/>
        <source>Do you want to abort the acquisition of %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Delete partial image files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-9"/>
        <source>Do you want to abort the verification of %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Abort?</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_DlgAcquire</name>
    <message>
        <location filename="dlgacquire.cpp" line="+212"/>
        <source>File format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+91"/>
        <source>Destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Configuration flag WriteToDevNull is set!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.h" line="+278"/>
        <location filename="table.cpp" line="+346"/>
        <source>EwfCaseNumber</source>
        <translation>Case number</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="table.cpp" line="+1"/>
        <source>EwfEvidenceNumber</source>
        <translation>Evidence number</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="table.cpp" line="+1"/>
        <source>EwfExaminer</source>
        <translation>Examiner</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="table.cpp" line="+1"/>
        <source>EwfDescription</source>
        <translation>Description</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="table.cpp" line="+1"/>
        <source>EwfNotes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>DestImageFilename</source>
        <translation>Image filename (without extension)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>DestInfoFilename</source>
        <translation>Info filename (without extension)</translation>
    </message>
    <message>
        <location filename="dlgacquire.cpp" line="+297"/>
        <source>Select destination directory</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-380"/>
        <location line="+1"/>
        <source>(file extension %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+688"/>
        <source>Special characters</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.h" line="-3"/>
        <source>DestImageDirectory</source>
        <translation>Image directory</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>DestInfoDirectory</source>
        <translation>Info directory</translation>
    </message>
    <message>
        <location filename="dlgacquire.cpp" line="-1075"/>
        <source>...</source>
        <comment>The directory browse button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+958"/>
        <source>Access denied</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.h" line="+2"/>
        <source>HashCalcMD5</source>
        <translation>Calculate MD5</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>HashCalcSHA256</source>
        <translation>Calculate SHA-256</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>HashVerifySrc</source>
        <translation>Re-read source after acquisition for verification (takes twice as long)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>HashVerifyDst</source>
        <translation>Verify image after acquisition (takes twice as long)</translation>
    </message>
    <message>
        <location filename="dlgacquire.cpp" line="-474"/>
        <source>Hash calculation / verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+475"/>
        <source>Guymager cannot write to the directory
	%1
This may be due to insufficient access rights or unsupported filename characters. Please choose another directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-798"/>
        <source>Local device, cannot be written</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Too small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>In use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Ok for cloning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+862"/>
        <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Files already used</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The image or info files already are used in the acquisition of %1. Please chose different ones.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Files exist</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>The image or info files already exist. Do you want to overwrite them?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-881"/>
        <source>Clone %1</source>
        <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Acquire image of %1</source>
        <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-163"/>
        <source>Device to be cloned</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Used in another clone operation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.h" line="-16"/>
        <source>SplitFileSize</source>
        <translation>Split size</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>SplitFileSwitch</source>
        <translation>Split image files</translation>
    </message>
    <message>
        <location filename="dlgacquire.cpp" line="+217"/>
        <source>(file extension %1 or %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+618"/>
        <location line="+15"/>
        <location line="+12"/>
        <source>Incorrect value</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-26"/>
        <source>The split file size &quot;%1&quot; is not valid. Only positive numbers can be entered.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+202"/>
        <source>The info file already exists. Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.h" line="+2"/>
        <source>SplitFileUnit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dlgacquire.cpp" line="-187"/>
        <source>The split size for the selected image format must be in the range %1MiB - %2EiB.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+213"/>
        <source>Large amount of segment files</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>With the chosen segment size, up to %1 image segment files could possibly be created. This would result in file extensions beyond .ZZZ
Do you accept such a large amount of files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Free space</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.h" line="+12"/>
        <source>HashCalcSHA1</source>
        <translation>Calculate SHA-1</translation>
    </message>
    <message>
        <location filename="dlgacquire.cpp" line="-1096"/>
        <source>Selected for first acquisition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+160"/>
        <source>Duplicate image of %1</source>
        <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Duplicate Clone %1</source>
        <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+570"/>
        <source>Path not found</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The destination directory
   %1
doesn&apos;t exist. Do you want to create it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+169"/>
        <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>
   Image directory:	%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>
   Image filename:	%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>
   Info directory:	%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>
   Info filename:	%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>
Do you accept these changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Destination in use</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The destination specified already is used for the first image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Info file in use</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The info file specified already is used for the first image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-595"/>
        <location line="+21"/>
        <source>Back...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-19"/>
        <location line="+20"/>
        <source>Duplicate image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-184"/>
        <source>Duplicate image settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+906"/>
        <source>There possibly is not enough space left on the destination path.
Source data size: %1
Free space on destination: %2

Do you want to continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_DlgAutoExit</name>
    <message>
        <location filename="dlgautoexit.cpp" line="+86"/>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Exit now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>All acquisitions have ended.
Guymager will exit automatically in %1 seconds.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_DlgDirSel</name>
    <message>
        <location filename="dlgdirsel.cpp" line="+27"/>
        <source>New directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Remove directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-42"/>
        <source>Select destination directory</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+56"/>
        <source>NewDirectory</source>
        <comment>Name of the new directory that will be created</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_DlgMessage</name>
    <message>
        <location filename="dlgmessage.cpp" line="+101"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_Info</name>
    <message>
        <location filename="info.cpp" line="+202"/>
        <source>Command executed: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>No information can be displayed as a timeout occurred while executing the command.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Information returned:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_InfoField</name>
    <message>
        <location filename="infofield.cpp" line="+110"/>
        <source>Size</source>
        <translation type="unfinished">Size</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sector size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Info file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Current speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>bytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Hash calculation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Source verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Started</source>
        <comment>Start timestamp and running time</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-30"/>
        <source>off</source>
        <comment>Hash calculation is off</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Image verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+88"/>
        <location line="+9"/>
        <location line="+6"/>
        <source>on</source>
        <comment>Display that verification is on</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-14"/>
        <location line="+9"/>
        <location line="+6"/>
        <source>off</source>
        <comment>Display that verification is off</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-114"/>
        <source>Additional state info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-22"/>
        <location line="+1"/>
        <location line="+2"/>
        <source>%1</source>
        <comment>Show which hash values are in use, % value wll be replaced by MD5, SHA-1, ...</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <location line="+2"/>
        <location line="+1"/>
        <source>%1 and %2</source>
        <comment>Show which hash values are in use, % value wll be replaced by MD5, SHA-1, ...</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1, %2 and %3</source>
        <comment>Show which hash values are in use, % value wll be replaced by MD5, SHA-1, ...</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_MainWindow</name>
    <message>
        <location filename="device.cpp" line="+399"/>
        <source>Local device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Cleanup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-355"/>
        <source>Aborted by user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="+292"/>
        <source>&amp;Rescan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+201"/>
        <source>Device already contained</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+160"/>
        <source>There are active acquisitions. Do you really want to abort them and quit?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Debug information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>About GUYMAGER</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>About Qt</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-86"/>
        <source>Exit GUYMAGER</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-356"/>
        <source>&amp;Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Misc</source>
        <comment>Menu entry</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Debug</source>
        <comment>Menu entry</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Help</source>
        <comment>Menu entry</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>About &amp;GUYMAGER</source>
        <comment>Menu entry</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>About &amp;Qt</source>
        <comment>Menu entry</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="device.cpp" line="+352"/>
        <source>Device disconnected, acquisition paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Device disconnected, verification paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+103"/>
        <source>Unknown</source>
        <comment>Media info string for informing about hidden areas (HPA/DCO)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <comment>Media info string for informing about hidden areas (HPA/DCO)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yes</source>
        <comment>Media info string for informing about hidden areas (HPA/DCO)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="-19"/>
        <source>Rescan devices and update table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Add special device</source>
        <comment>Menu entry</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+161"/>
        <source>Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <location line="+2"/>
        <source>Invalid device</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Manually added special device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>The selected file or device already is contained in the table.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-12"/>
        <source>The device or file cannot be selected because its size is unknown.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>The device or file cannot be selected because it contains 0 bytes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="device.cpp" line="-168"/>
        <source>Used in clone operation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Aborting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+163"/>
        <source>none</source>
        <comment>column hidden areas</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>unknown</source>
        <comment>column hidden areas</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="-179"/>
        <source>Exit after acquisitions completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+417"/>
        <source>(not used as Guymager currently is configured to use its own EWF module)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>GUYMAGER is a Linux-based forensic imaging tool

Version: %1
Compilation timestamp: %2
Compiled with gcc %3
Linked with libewf %4 %5
Linked with libguytools %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="device.cpp" line="-468"/>
        <source>Acquisition start failure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Device read error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Image write error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Image verify error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Info file write error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Image 1 write error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Image 1 verify error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Info file 1 write error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image 2 write error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Image 2 verify error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Info file 2 write error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+278"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Verifying</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+53"/>
        <location line="+26"/>
        <source>Verified &amp; ok</source>
        <comment>Status column</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-20"/>
        <source>image 1 failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>verification 1 failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>image 1 ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>image 2 failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>verification 2 failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>image 2 ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+20"/>
        <source>source verification failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-10"/>
        <source>image failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>verification failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-395"/>
        <source>Too many bad sectors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Disconnect timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+296"/>
        <source>Queued</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_Table</name>
    <message>
        <location filename="table.cpp" line="-190"/>
        <source>Local Device - cannot be acquired</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-38"/>
        <source>Info</source>
        <comment>Context menu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+149"/>
        <source>Device info</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+26"/>
        <source>GUYMAGER ACQUISITION INFO FILE</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Guymager</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Device information</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+579"/>
        <source>Finished successfully</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>(with %1 bad sectors)</source>
        <comment>Info file, may be appended to &apos;finished successfully&apos; message</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-45"/>
        <source>Aborted by user</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Aborted because of image write error</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Strange state (%1)</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>State: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-174"/>
        <source>During verification, %1 bad sectors have been encountered. The sector numbers are:</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>During acquisition, %1 bad sectors have been encountered. They have been replaced by zeroed sectors. The sector numbers are:</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+46"/>
        <source>No bad sectors encountered during verification.</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>No bad sectors encountered during acquisition.</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+58"/>
        <source>(during acquisition)</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+106"/>
        <source>(ISO format YYYY-MM-DD HH:MM:SS)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Acquisition aborted before start of verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-642"/>
        <source>Linux device:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Device size:: %1 (%2)</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+643"/>
        <location line="+24"/>
        <source>Acquisition started:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-23"/>
        <source>Verification started:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+23"/>
        <source>Ended:: %1 (%2 hours, %3 minutes and %4 seconds)</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-15"/>
        <location line="+21"/>
        <source>Acquisition speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-164"/>
        <source>--</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+83"/>
        <source>MD5 hash:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-619"/>
        <source>Version:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Compilation timestamp:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Compiled with:: %1 %2</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>libewf version:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>libguytools version:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+683"/>
        <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-639"/>
        <source>Source verification:: on</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Source verification:: off</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+507"/>
        <source>(during source verification)</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+69"/>
        <source>SHA256 hash:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-584"/>
        <source>Image path and file name:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Host name:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Domain name:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>System:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Info  path and file name:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Image verification:: on</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Image verification:: off</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+516"/>
        <source>Aborted, too many bad sectors (&gt; %1)</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Aborted because device has been inaccessible for too long (&gt; %1s)</source>
        <oldsource>Aborted because device has is inaccessible for too long (&gt; %1s)</oldsource>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Aborted because of image read error during verification</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>MD5 hash verified source:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>MD5 hash verified image:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>SHA256 hash verified source:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SHA256 hash verified image:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Source verification OK. The device delivered the same data during acquisition and verification.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Source verification FAILED. The device didn&apos;t deliver the same data during acquisition and verification. Check if the defect sector list was the same during acquisition and verification (see above).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Image verification OK. The image contains exactely the data that was written.</source>
        <translation>Image verification OK. The image contains exactly the data that was written.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Image verification FAILED. The data in the image is different from what was written.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Maybe you try to acquire the device again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-839"/>
        <source>Remove special device</source>
        <comment>Context menu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+222"/>
        <source>Image meta data</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-4"/>
        <source> - file extension is %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-222"/>
        <source>Acquire image</source>
        <comment>Context menu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Clone device</source>
        <comment>Context menu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Abort</source>
        <comment>Context menu</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+212"/>
        <source>Acquisition</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Format:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-178"/>
        <source>Device used for cloning - cannot be acquired</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+861"/>
        <source>Generated image files and their MD5 hashes</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>No MD5 hashes available (image verification checkbox was switched off)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>No MD5 hashes available (configuration parameter CalcImageFileMD5 is off)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-876"/>
        <source>Cannot be acquired - see additional state info field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+734"/>
        <source>Aborted because of info file write error</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-21"/>
        <source>Aborted because acquisition failed to start</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+154"/>
        <source>No MD5 hashes available (the selected EWF format does not support image file hashes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-672"/>
        <source>Hash calculation:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+521"/>
        <source>Aborted because of source read error</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Aborted, strange reason (%1 %2)</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+37"/>
        <source>SHA1 hash:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SHA1 hash verified source:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SHA1 hash verified image:: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-607"/>
        <source>Hidden areas: %1</source>
        <comment>Info file</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+725"/>
        <source>Acquisition/verification aborted - file list may be incomplete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>t_ThreadScan</name>
    <message>
        <location filename="threadscan.cpp" line="+53"/>
        <source>Cannot scan devices</source>
        <comment>Dialog title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None of the device scan methods worked. Exiting now.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
